Add a social media caption to a ggplot or gt table.
Usage
add_caption_cwb(
type = c("plot", "table"),
include_data_source = FALSE,
data_source = NULL,
github_username = "colebaril",
bluesky_username = "@colebaril.ca"
)Add a social media caption to a ggplot or gt table.
add_caption_cwb(
type = c("plot", "table"),
include_data_source = FALSE,
data_source = NULL,
github_username = "colebaril",
bluesky_username = "@colebaril.ca"
)